@@ -1,21 +1,25 @@
 """Core class for the Daymet functions."""
+from __future__ import annotations
+
 import functools
 import warnings
+from dataclasses import dataclass
 from datetime import datetime
-from typing import Dict, Iterable, List, Optional, Tuple, TypeVar, Union
+from typing import Iterable, TypeVar
 
 import numpy as np
 import pandas as pd
 import shapely.geometry as sgeom
 import xarray as xr
-from pydantic import BaseModel, validator
 
 from .exceptions import InputRangeError, InputTypeError, InputValueError
 
 try:
+    from numba import config as numba_config
     from numba import njit, prange
 
     ngjit = functools.partial(njit, cache=True, nogil=True, parallel=True)
+    numba_config.THREADING_LAYER = "workqueue"
     HAS_NUMBA = True
 except ImportError:
     HAS_NUMBA = False
@@ -33,7 +37,6 @@ except ImportError:
 
 
 DF = TypeVar("DF", pd.DataFrame, xr.Dataset)
-DEF_CRS = "epsg:4326"
 DATE_FMT = "%Y-%m-%d"
 
 # Default snow params from https://doi.org/10.5194/gmd-11-1077-2018
@@ -43,7 +46,8 @@ T_SNOW = 0.6  # degC
 __all__ = ["Daymet"]
 
 
-class DaymetBase(BaseModel):
+@dataclass
+class DaymetBase:
     """Base class for validating Daymet requests.
 
     Parameters
@@ -79,56 +83,41 @@ class DaymetBase(BaseModel):
     .. footbibliography::
     """
 
-    pet: Optional[str] = None
-    snow: bool = False
-    time_scale: str = "daily"
-    variables: List[str] = ["all"]
-    region: str = "na"
+    pet: str | None
+    snow: bool
+    time_scale: str
+    variables: Iterable[str]
+    region: str
 
-    @validator("pet")
-    @classmethod
-    def _pet(cls, v: Optional[str]) -> Optional[str]:
+    def __post_init__(self) -> None:
         valid_methods = ["penman_monteith", "hargreaves_samani", "priestley_taylor", None]
-        if v not in valid_methods:
+        if self.pet not in valid_methods:
             raise InputValueError("pet", valid_methods)
-        return v
 
-    @validator("variables")
-    @classmethod
-    def _variables(cls, v: List[str], values: Dict[str, str]) -> List[str]:
         valid_variables = ["dayl", "prcp", "srad", "swe", "tmax", "tmin", "vp"]
-        if "all" in v:
-            return valid_variables
+        if "all" in self.variables:
+            self.variables = valid_variables
 
-        if not set(v).issubset(set(valid_variables)):
+        if not set(self.variables).issubset(set(valid_variables)):
             raise InputValueError("variables", valid_variables)
 
-        if values["pet"] is not None:
-            v = list(set(v).union({"tmin", "tmax", "srad", "dayl"}))
+        if self.pet is not None:
+            self.variables = list(set(self.variables).union({"tmin", "tmax", "srad", "dayl"}))
 
-        if values["snow"]:
-            v = list(set(v).union({"tmin"}))
-        return v
+        if self.snow:
+            self.variables = list(set(self.variables).union({"tmin"}))
 
-    @validator("time_scale")
-    @classmethod
-    def _timescales(cls, v: str, values: Dict[str, str]) -> str:
         valid_timescales = ["daily", "monthly", "annual"]
-        if v not in valid_timescales:
+        if self.time_scale not in valid_timescales:
             raise InputValueError("time_scale", valid_timescales)
 
-        if values["pet"] is not None and v != "daily":
-            msg = "PET can only be computed at daily scale i.e., time_scale must be daily."
-            raise InputRangeError(msg)
-        return v
+        if self.pet is not None and self.time_scale != "daily":
+            msg = "time_scale when pet is True"
+            raise InputValueError(msg, ["daily"])
 
-    @validator("region")
-    @classmethod
-    def _regions(cls, v: str) -> str:
         valid_regions = ["na", "hi", "pr"]
-        if v not in valid_regions:
+        if self.region not in valid_regions:
             raise InputValueError("region", valid_regions)
-        return v
 
 
 @ngjit("f8[::1](f8[::1], f8[::1], f8, f8)")  # type: ignore
@@ -187,8 +176,8 @@ class Daymet:
 
     def __init__(
         self,
-        variables: Optional[Union[Iterable[str], str]] = None,
-        pet: Optional[str] = None,
+        variables: Iterable[str] | str | None = None,
+        pet: str | None = None,
         snow: bool = False,
         time_scale: str = "daily",
         region: str = "na",
@@ -210,21 +199,12 @@ class Daymet:
             "hi": sgeom.box(-160.3055, 17.9539, -154.7715, 23.5186),
             "pr": sgeom.box(-67.9927, 16.8443, -64.1195, 19.9381),
         }
-        self.invalid_bbox_msg = "\n".join(
-            [
-                f"Input coordinates are outside the Daymet range for region ``{region}``.",
-                f"Valid bounding box is: {self.region_bbox[region].bounds}",
-            ]
-        )
         if self.region == "pr":
             self.valid_start = pd.to_datetime("1950-01-01")
         else:
             self.valid_start = pd.to_datetime("1980-01-01")
         self.valid_end = pd.to_datetime(f"{datetime.now().year - 1}-12-31")
-        self._invalid_yr = (
-            "Daymet database ranges from " + f"{self.valid_start.year} to {self.valid_end.year}."
-        )
-        self.time_codes = {"daily": 1840, "monthly": 1855, "annual": 1852}
+        self.time_codes = {"daily": 2129, "monthly": 2131, "annual": 2130}
 
         self.daymet_table = pd.DataFrame(
             {
@@ -240,39 +220,83 @@ class Daymet:
                 "Abbr": ["dayl", "prcp", "srad", "swe", "tmax", "tmin", "vp"],
                 "Units": ["s/day", "mm/day", "W/m2", "kg/m2", "degrees C", "degrees C", "Pa"],
                 "Description": [
-                    "Duration of the daylight period in seconds per day. "
-                    + "This calculation is based on the period of the day during which the "
-                    + "sun is above a hypothetical flat horizon",
-                    "Daily total precipitation in millimeters per day, sum of"
-                    + " all forms converted to water-equivalent. Precipitation occurrence on "
-                    + "any given day may be ascertained.",
-                    "Incident shortwave radiation flux density in watts per square meter, "
-                    + "taken as an average over the daylight period of the day. "
-                    + "NOTE: Daily total radiation (MJ/m2/day) can be calculated as follows: "
-                    + "((srad (W/m2) * dayl (s/day)) / l,000,000)",
-                    "Snow water equivalent in kilograms per square meter."
-                    + " The amount of water contained within the snowpack.",
+                    " ".join(
+                        [
+                            "Duration of the daylight period in seconds per day.",
+                            "This calculation is based on the period of the day during which the",
+                            "sun is above a hypothetical flat horizon",
+                        ]
+                    ),
+                    " ".join(
+                        [
+                            "Daily total precipitation in millimeters per day, sum of",
+                            "all forms converted to water-equivalent. Precipitation occurrence on",
+                            "any given day may be ascertained.",
+                        ]
+                    ),
+                    " ".join(
+                        [
+                            "Incident shortwave radiation flux density in watts per square meter,",
+                            "taken as an average over the daylight period of the day.",
+                            "NOTE: Daily total radiation (MJ/m2/day) can be calculated as",
+                            "follows: ((srad (W/m2) * dayl (s/day)) / l,000,000)",
+                        ]
+                    ),
+                    " ".join(
+                        [
+                            "Snow water equivalent in kilograms per square meter."
+                            "The amount of water contained within the snowpack."
+                        ]
+                    ),
                     "Daily maximum 2-meter air temperature in degrees Celsius.",
                     "Daily minimum 2-meter air temperature in degrees Celsius.",
-                    "Water vapor pressure in pascals. Daily average partial pressure of water vapor.",
+                    " ".join(
+                        [
+                            "Water vapor pressure in pascals. Daily average partial",
+                            "pressure of water vapor.",
+                        ]
+                    ),
                 ],
             }
         )
 
         self.units = dict(zip(self.daymet_table["Abbr"], self.daymet_table["Units"]))
+        self.units["snow"] = "mm/day"
+        self.units["pet"] = "mm/day"
+
+        self.long_names = dict(zip(self.daymet_table["Abbr"], self.daymet_table["Parameter"]))
+        self.long_names["snow"] = "Snow"
+        self.long_names["pet"] = "Potential Evapotranspiration"
+
+        self.descriptions = dict(zip(self.daymet_table["Abbr"], self.daymet_table["Description"]))
+        self.descriptions["snow"] = " ".join(
+            [
+                "Daily total snow in millimeters per day,",
+                "computed by partitioning the total precipitation into snow and rain.",
+            ]
+        )
+        if self.pet:
+            self.descriptions["pet"] = " ".join(
+                [
+                    "Daily potential evapotranspiration in millimeters per day,",
+                    f"computed using the {self.pet.replace('_', '-').title()} method.",
+                ]
+            )
 
     @staticmethod
-    def check_dates(dates: Union[Tuple[str, str], Union[int, List[int]]]) -> None:
+    def check_dates(dates: tuple[str, str] | int | list[int]) -> None:
         """Check if input dates are in correct format and valid."""
-        if not isinstance(dates, (tuple, list, int)):
+        if not isinstance(dates, (tuple, list, int, range)):
             raise InputTypeError(
-                "dates", "tuple, list, or int", "(start, end), year, or [years, ...]"
+                "dates",
+                "tuple, list, range, or int",
+                "(start, end), range(start, end), or [years, ...]",
             )
 
         if isinstance(dates, tuple) and len(dates) != 2:
             raise InputTypeError("dates", "Start and end should be passed as a tuple of length 2.")
 
-    def dates_todict(self, dates: Tuple[str, str]) -> Dict[str, str]:
+    def dates_todict(self, dates: tuple[str, str]) -> dict[str, str]:
         """Set dates by start and end dates as a tuple, (start, end)."""
         if not isinstance(dates, tuple) or len(dates) != 2:
             raise InputTypeError("dates", "tuple", "(start, end)")
@@ -288,23 +312,25 @@ class Daymet:
             end = end.replace(day=8)
 
         if start < self.valid_start or end > self.valid_end:
-            raise InputRangeError(self._invalid_yr)
+            raise InputRangeError("start/end", f"from {self.valid_start} to {self.valid_end}")
 
         return {
             "start": start.strftime(DATE_FMT),
             "end": end.strftime(DATE_FMT),
         }
 
-    def years_todict(self, years: Union[List[int], int]) -> Dict[str, str]:
+    def years_todict(self, years: list[int] | int | range) -> dict[str, str]:
         """Set date by list of year(s)."""
-        years = [years] if isinstance(years, int) else years
+        years = [years] if isinstance(years, int) else list(years)
 
         if min(years) < self.valid_start.year or max(years) > self.valid_end.year:
-            raise InputRangeError(self._invalid_yr)
+            raise InputRangeError(
+                "start/end", f"from {self.valid_start.year} to {self.valid_end.year}"
+            )
 
         return {"years": ",".join(str(y) for y in years)}
 
-    def dates_tolist(self, dates: Tuple[str, str]) -> List[Tuple[pd.Timestamp, pd.Timestamp]]:
+    def dates_tolist(self, dates: tuple[str, str]) -> list[tuple[pd.Timestamp, pd.Timestamp]]:
         """Correct dates for Daymet accounting for leap years.
 
         Daymet doesn't account for leap years and removes Dec 31 when
@@ -331,7 +357,7 @@ class Daymet:
         years = [_period[_period.year == y] for y in _period.year.unique()]
         return [(y[0], y[-1]) for y in years]
 
-    def years_tolist(self, years: Union[List[int], int]) -> List[Tuple[pd.Timestamp, pd.Timestamp]]:
+    def years_tolist(self, years: list[int] | int) -> list[tuple[pd.Timestamp, pd.Timestamp]]:
         """Correct dates for Daymet accounting for leap years.
 
         Daymet doesn't account for leap years and removes Dec 31 when
