@@ -1,5 +1,7 @@
 """Core class for the Daymet functions."""
-from typing import Dict, Hashable, Iterable, KeysView, Optional, Tuple, TypeVar, Union
+from __future__ import annotations
+
+from typing import Hashable, Iterable, KeysView, TypeVar, Union
 
 import numpy as np
 import pandas as pd
@@ -10,7 +12,7 @@ import xarray as xr
 
 from .exceptions import InputTypeError, InputValueError, MissingItemError
 
-DEF_CRS = "epsg:4326"
+CRSTYPE = Union[int, str, pyproj.CRS]
 DF = TypeVar("DF", pd.DataFrame, xr.Dataset)
 DS = TypeVar("DS", pd.Series, xr.DataArray)
 
@@ -40,8 +42,8 @@ def saturation_vapour(temperature: DS) -> DS:
 def vapour_pressure(
     tmax_c: DS,
     tmin_c: DS,
-    rh: Optional[DS] = None,
-) -> Union[Tuple[DS, DS], Tuple[DS, DS]]:
+    rh: DS | None = None,
+) -> tuple[DS, DS] | tuple[DS, DS]:
     """Compute saturation and actual vapour pressure :footcite:t:`Allen_1998` Eq. 12 [kPa].
 
     Parameters
@@ -73,8 +75,8 @@ def vapour_pressure(
 
 
 def extraterrestrial_radiation(
-    dayofyear: Union[pd.Index, xr.DataArray], lat: Union[float, xr.DataArray]
-) -> Union[pd.Index, xr.DataArray]:
+    dayofyear: pd.Index | xr.DataArray, lat: float | xr.DataArray
+) -> pd.Index | xr.DataArray:
     """Compute Extraterrestrial Radiation using :footcite:t:`Allen_1998` Eq. 28 [MJ m^-2 h^-1].
 
     Parameters
@@ -111,11 +113,11 @@ def extraterrestrial_radiation(
 def net_radiation(
     srad: DS,
     dayl: DS,
-    elevation: Union[float, xr.DataArray],
+    elevation: float | xr.DataArray,
     tmax: DS,
     tmin: DS,
     e_a: DS,
-    rad_a: Union[pd.Index, xr.DataArray],
+    rad_a: pd.Index | xr.DataArray,
 ) -> DS:
     """Compute net radiation using :footcite:t:`Allen_1998` Eq. 40 [MJ m^-2 day^-1].
 
@@ -159,7 +161,7 @@ def net_radiation(
     return rad_ns - rad_nl
 
 
-def psychrometric_constant(elevation: Union[float, xr.DataArray], lmbda: DS) -> DS:
+def psychrometric_constant(elevation: float | xr.DataArray, lmbda: DS) -> DS:
     """Compute the psychrometric constant :footcite:t:`Allen_1998` Eq. 8 [kPa °C^-1]..
 
     Parameters
@@ -212,7 +214,7 @@ def vapour_slope(tmean_c: DS) -> DS:
     )
 
 
-def check_requirements(reqs: Iterable[str], cols: Union[KeysView[Hashable], pd.Index]) -> None:
+def check_requirements(reqs: Iterable[str], cols: KeysView[Hashable] | pd.Index) -> None:
     """Check for all the required data.
 
     Parameters
@@ -238,14 +240,14 @@ class PETCoords:
     clm : DataFrame
         For ``penman_monteith`` method, the dataset must include at least the following variables:
         ``tmin (degrees C)``, ``tmax (degrees C)``, ``srad (W/m2)``, and ``dayl (s)``.
-        Also, if ``rh (-)`` (relative humidity) and ``u2 (m/s)`` (wind at 2 m level)
+        Also, if ``rh (-)`` (relative humidity) and ``u2m (m/s)`` (wind at 2 m level)
         are available, they are used. Otherwise, actual vapour pressure is assumed
         to be saturation vapour pressure at daily minimum temperature and 2-m wind
         speed is considered to be 2 m/s. For the ``hargreaves_samani`` method, the dataset
         must include ``tmin (degrees C)`` and ``tmax (degrees C)``.
     coords : tuple of floats
         Coordinates of the daymet data location as a tuple, (x, y).
-    crs : str, optional
+    crs : str, int, or pyproj.CRS, optional
         The spatial reference of the input coordinate, defaults to epsg:4326.
     params : dict, optional
         Model-specific parameters as a dictionary, defaults to ``None``.
@@ -254,12 +256,12 @@ class PETCoords:
     def __init__(
         self,
         clm: pd.DataFrame,
-        coords: Tuple[float, float],
-        crs: Union[str, pyproj.CRS] = DEF_CRS,
-        params: Optional[Dict[str, float]] = None,
+        coords: tuple[float, float],
+        crs: CRSTYPE = 4326,
+        params: dict[str, float] | None = None,
     ) -> None:
         self.clm = clm
-        self.coords = ogc.utils.match_crs([coords], crs, DEF_CRS)[0]
+        self.coords = ogc.utils.match_crs([coords], crs, 4326)[0]
         self.params = params if isinstance(params, dict) else {"soil_heat": 0.0}
 
         # recommended when no data is not available to estimate soil heat flux
@@ -271,7 +273,7 @@ class PETCoords:
         self.srad = "srad (W/m2)"
         self.dayl = "dayl (s)"
         self.rh = "rh (-)"
-        self.u2 = "u2 (m/s)"
+        self.u2m = "u2m (m/s)"
 
         self.tmean = 0.5 * (self.clm[self.tmax] + self.clm[self.tmin])
         self.clm_vars = self.clm.columns
@@ -323,7 +325,7 @@ class PETCoords:
         )
 
         # recommended when no data is not available to estimate wind speed
-        u_2m = self.clm[self.u2] if self.u2 in self.clm else 2.0
+        u_2m = self.clm[self.u2m] if self.u2m in self.clm else 2.0
         self.clm["pet (mm/day)"] = (
             0.408 * vp_slope * (rad_n - self.params["soil_heat"])
             + gamma * 900.0 / (self.tmean + 273.0) * u_2m * (e_s - e_a)
@@ -420,7 +422,7 @@ class PETGridded:
     clm : xarray.DataArray
         For ``penman_monteith`` method, the dataset must include at least the following variables:
         ``tmin``, ``tmax``, ``lat``, ``lon``, ``srad``, ``dayl``. Also, if
-        ``rh`` (relative humidity) and ``u2`` (wind at 2 m level)
+        ``rh`` (relative humidity) and ``u2m`` (wind at 2 m level)
         are available, they are used. Otherwise, actual vapour pressure is assumed
         to be saturation vapour pressure at daily minimum temperature and 2-m wind
         speed is considered to be 2 m/s. For the ``hargreaves_samani`` method, the dataset
@@ -432,7 +434,7 @@ class PETGridded:
     def __init__(
         self,
         clm: xr.Dataset,
-        params: Optional[Dict[str, float]] = None,
+        params: dict[str, float] | None = None,
     ) -> None:
         self.clm = clm.copy()
         self.params = params if isinstance(params, dict) else {"soil_heat": 0.0}
@@ -518,7 +520,7 @@ class PETGridded:
         )
 
         # recommended when no data is not available to estimate wind speed
-        u_2m = self.clm["u2"] if "u2" in self.clm_vars else 2.0
+        u_2m = self.clm["u2m"] if "u2m" in self.clm_vars else 2.0
         self.clm["pet"] = (
             0.408 * self.clm["vp_slope"] * (self.clm["rad_n"] - self.params["soil_heat"])
             + self.clm["gamma"]
@@ -622,10 +624,10 @@ class PETGridded:
 
 def potential_et(
     clm: DF,
-    coords: Optional[Tuple[float, float]] = None,
-    crs: Union[str, pyproj.CRS] = DEF_CRS,
+    coords: tuple[float, float] | None = None,
+    crs: CRSTYPE = 4326,
     method: str = "hargreaves_samani",
-    params: Optional[Dict[str, float]] = None,
+    params: dict[str, float] | None = None,
 ) -> DF:
     """Compute Potential EvapoTranspiration for both gridded and a single location.
 
@@ -651,7 +653,7 @@ def potential_et(
         ``srad (W/m2)``      ``srad``
         ``dayl (s)``         ``dayl``
         ``rh (-)``           ``rh``
-        ``u2 (m/s)``         ``u2``
+        ``u2m (m/s)``        ``u2``
         ==================== ========
 
         If relative humidity and wind speed at 2-m level are not available,
@@ -660,7 +662,7 @@ def potential_et(
     coords : tuple of floats, optional
         Coordinates of the daymet data location as a tuple, (x, y). This is required when ``clm``
         is a ``DataFrame``.
-    crs : str, optional
+    crs : str, int, or pyproj.CRS, optional
         The spatial reference of the input coordinate, defaults to ``epsg:4326``. This is only used
         when ``clm`` is a ``DataFrame``.
     method : str, optional
@@ -692,7 +694,7 @@ def potential_et(
     if not isinstance(clm, (pd.DataFrame, xr.Dataset)):
         raise InputTypeError("clm", "pd.DataFrame or xr.Dataset")
 
-    pet: Union[PETCoords, PETGridded]
+    pet: PETCoords | PETGridded
     if isinstance(clm, pd.DataFrame):
         if coords is None:
             raise MissingItemError(["coords"])
@@ -700,5 +702,5 @@ def potential_et(
         pet = PETCoords(clm, coords, crs, params)
     else:
         pet = PETGridded(clm, params)
-    with xr.set_options(keep_attrs=True):  # type: ignore
+    with xr.set_options(keep_attrs=True):
         return getattr(pet, method)()  # type: ignore
