@@ -3,6 +3,9 @@
 The original script is from
 `xarray <https://github.com/pydata/xarray/blob/master/xarray/util/print_versions.py>`__
 """
+from __future__ import annotations
+
+import contextlib
 import importlib
 import locale
 import os
@@ -10,13 +13,32 @@ import platform
 import struct
 import subprocess
 import sys
-from types import ModuleType
-from typing import List, Optional, TextIO, Tuple
+from typing import TYPE_CHECKING, TextIO
+
+if TYPE_CHECKING:
+    from types import ModuleType
 
 __all__ = ["show_versions"]
 
 
-def get_sys_info() -> List[Tuple[str, Optional[str]]]:
+def netcdf_and_hdf5_versions() -> list[tuple[str, str | None]]:
+    libhdf5_version = None
+    libnetcdf_version = None
+    try:
+        import netCDF4
+
+        libhdf5_version = netCDF4.__hdf5libversion__
+        libnetcdf_version = netCDF4.__netcdf4libversion__
+    except (ImportError, AttributeError):
+        with contextlib.suppress(ImportError, AttributeError):
+            import h5py
+
+            libhdf5_version = h5py.version.hdf5_version
+
+    return [("libhdf5", libhdf5_version), ("libnetcdf", libnetcdf_version)]
+
+
+def get_sys_info() -> list[tuple[str, str | None]]:
     """Return system information as a dict.
 
     From https://github.com/numpy/numpy/blob/master/setup.py#L64-L89
@@ -28,10 +50,10 @@ def get_sys_info() -> List[Tuple[str, Optional[str]]]:
     """
     blob = []
 
-    def _minimal_ext_cmd(cmd: List[str]) -> bytes:
+    def _minimal_ext_cmd(cmd: list[str]) -> bytes:
         # construct minimal environment
         env = {}
-        for k in ["SYSTEMROOT", "PATH", "HOME"]:
+        for k in ("SYSTEMROOT", "PATH", "HOME"):
             v = os.environ.get(k)
             if v is not None:
                 env[k] = v
@@ -71,22 +93,13 @@ def get_sys_info() -> List[Tuple[str, Optional[str]]]:
     return blob
 
 
-def netcdf_and_hdf5_versions() -> List[Tuple[str, Optional[str]]]:
-    libhdf5_version = None
-    libnetcdf_version = None
+def _get_mod(modname: str) -> ModuleType:
+    if modname in sys.modules:
+        return sys.modules[modname]
     try:
-        import netCDF4
-
-        libhdf5_version = netCDF4.__hdf5libversion__
-        libnetcdf_version = netCDF4.__netcdf4libversion__
-    except (ImportError, AttributeError):
-        try:
-            import h5py
-
-            libhdf5_version = h5py.version.hdf5_version
-        except (ImportError, AttributeError):
-            pass
-    return [("libhdf5", libhdf5_version), ("libnetcdf", libnetcdf_version)]
+        return importlib.import_module(modname)
+    except ModuleNotFoundError:
+        return importlib.import_module(modname.replace("-", "_"))
 
 
 def show_versions(file: TextIO = sys.stdout) -> None:
@@ -105,14 +118,12 @@ def show_versions(file: TextIO = sys.stdout) -> None:
         ("aiohttp-client-cache", lambda mod: mod.__version__),
         ("aiosqlite", lambda mod: mod.__version__),
         ("brotli", lambda mod: mod.__version__),
-        ("cchardet", lambda mod: mod.__version__),
         ("cytoolz", lambda mod: mod.__version__),
         ("ujson", lambda mod: mod.__version__),
         #  pygeoogc
         ("pygeoogc", lambda mod: mod.__version__),
         ("defusedxml", lambda mod: mod.__version__),
         ("owslib", lambda mod: mod.__version__),
-        ("pydantic", lambda mod: mod.version.VERSION),
         ("yaml", lambda mod: mod.__version__),
         ("pyproj", lambda mod: mod.__version__),
         ("requests", lambda mod: mod.__version__),
@@ -145,7 +156,10 @@ def show_versions(file: TextIO = sys.stdout) -> None:
         ("matplotlib", lambda mod: mod.__version__),
         #  pydaymet
         ("pydaymet", lambda mod: mod.__version__),
+        #  hydrosignatures
+        ("hydrosignatures", lambda mod: mod.__version__),
         #  misc
+        ("numba", lambda mod: mod.__version__),
         ("bottleneck", lambda mod: mod.__version__),
         ("pygeos", lambda mod: mod.__version__),
         ("tables", lambda mod: mod.__version__),
@@ -155,7 +169,7 @@ def show_versions(file: TextIO = sys.stdout) -> None:
         ("xdist", lambda mod: mod.__version__),
     ]
 
-    deps_blob: List[Tuple[str, Optional[str]]] = []
+    deps_blob: list[tuple[str, str | None]] = []
     for (modname, ver_f) in deps:
         try:
             mod = _get_mod(modname)
@@ -163,7 +177,7 @@ def show_versions(file: TextIO = sys.stdout) -> None:
             deps_blob.append((modname, None))
         else:
             try:
-                ver = ver_f(mod)  # type: ignore
+                ver = ver_f(mod)
             except (NotImplementedError, AttributeError):
                 ver = "installed"
             deps_blob.append((modname, ver))
@@ -177,12 +191,3 @@ def show_versions(file: TextIO = sys.stdout) -> None:
     print("", file=file)
     for k, stat in sorted(deps_blob):
         print(f"{k}: {stat}", file=file)
-
-
-def _get_mod(modname: str) -> ModuleType:
-    if modname in sys.modules:
-        return sys.modules[modname]
-    try:
-        return importlib.import_module(modname)
-    except ModuleNotFoundError:
-        return importlib.import_module(modname.replace("-", "_"))
