@@ -1,10 +1,12 @@
 """Tests for PyDaymet package."""
 import io
 import shutil
+import sys
 from pathlib import Path
 
 import cytoolz as tlz
 import geopandas as gpd
+import numpy as np
 import pandas as pd
 import pytest
 from shapely.geometry import Polygon
@@ -12,19 +14,8 @@ from shapely.geometry import Polygon
 import pydaymet as daymet
 from pydaymet.cli import cli
 
-try:
-    import typeguard  # noqa: F401
-
-    hastypeguard = True
-except ImportError:
-    hastypeguard = False
-
-try:
-    import numba  # noqa: F401
-
-    hasnumba = True
-except ImportError:
-    hasnumba = False
+has_typeguard = True if sys.modules.get("typeguard") else False
+has_numba = True if sys.modules.get("numba") else False
 
 GEOM = Polygon(
     [[-69.77, 45.07], [-69.31, 45.07], [-69.31, 45.45], [-69.77, 45.45], [-69.77, 45.07]]
@@ -32,11 +23,14 @@ GEOM = Polygon(
 DAY = ("2000-01-01", "2000-01-12")
 YEAR = 2010
 VAR = ["prcp", "tmin"]
-DEF_CRS = "epsg:4326"
-ALT_CRS = "epsg:3542"
+DEF_CRS = 4326
+ALT_CRS = 3542
 COORDS = (-1431147.7928, 318483.4618)
 DATES = ("2000-01-01", "2000-12-31")
-SMALL = 1e-3
+
+
+def assert_close(a: float, b: float, rtol: float = 1e-3) -> bool:
+    assert np.isclose(a, b, rtol=rtol).all()
 
 
 class TestByCoords:
@@ -45,75 +39,69 @@ class TestByCoords:
         [("hargreaves_samani", 3.713), ("priestley_taylor", 3.175), ("penman_monteith", 3.472)],
     )
     def test_pet(self, method, expected):
-        clm = daymet.get_bycoords(COORDS, DATES, crs=ALT_CRS, pet=method, ssl=False)
-        assert abs(clm["pet (mm/day)"].mean() - expected) < SMALL
+        clm = daymet.get_bycoords(COORDS, DATES, crs=ALT_CRS, pet=method)
+        assert_close(clm["pet (mm/day)"].mean(), expected)
 
-    @pytest.mark.skipif(hastypeguard and hasnumba, reason="typeguard doesn't work with numba")
+    @pytest.mark.skipif(has_typeguard and has_numba, reason="typeguard doesn't work with numba")
     def test_snow(self):
-        clm = daymet.get_bycoords(COORDS, DATES, snow=True, crs=ALT_CRS, ssl=False)
-        assert abs(clm["snow (mm/day)"].mean()) < SMALL
+        clm = daymet.get_bycoords(COORDS, DATES, snow=True, crs=ALT_CRS)
+        assert_close(clm["snow (mm/day)"].mean(), 0.0)
 
     def test_daily(self):
-        clm = daymet.get_bycoords(COORDS, DATES, variables=VAR, crs=ALT_CRS, ssl=False)
-        assert abs(clm["prcp (mm/day)"].mean() - 1.005) < SMALL
+        clm = daymet.get_bycoords(COORDS, DATES, variables=VAR, crs=ALT_CRS)
+        clm_ds = daymet.get_bycoords(COORDS, DATES, variables=VAR, crs=ALT_CRS, to_xarray=True)
+
+        expected = 1.005
+        assert_close(clm["prcp (mm/day)"].mean(), expected)
+        assert_close(clm_ds.prcp.mean(), expected)
 
     def test_monthly(self):
-        clm = daymet.get_bycoords(
-            COORDS, YEAR, variables=VAR, crs=ALT_CRS, time_scale="monthly", ssl=False
-        )
-        assert abs(clm["tmin (degrees C)"].mean() - 11.435) < SMALL
+        clm = daymet.get_bycoords(COORDS, YEAR, variables=VAR, crs=ALT_CRS, time_scale="monthly")
+        assert_close(clm["tmin (degrees C)"].mean(), 11.435)
 
     def test_annual(self):
-        clm = daymet.get_bycoords(
-            COORDS, YEAR, variables=VAR, crs=ALT_CRS, time_scale="annual", ssl=False
-        )
-        assert abs(clm["tmin (degrees C)"].mean() - 11.458) < SMALL
+        clm = daymet.get_bycoords(COORDS, YEAR, variables=VAR, crs=ALT_CRS, time_scale="annual")
+        assert_close(clm["tmin (degrees C)"].mean(), 11.458)
 
 
 class TestByGeom:
     @pytest.mark.parametrize(
         "method,expected",
-        [("hargreaves_samani", 0.453), ("priestley_taylor", 0.119), ("penman_monteith", 0.627)],
+        [("hargreaves_samani", 0.4525), ("priestley_taylor", 0.119), ("penman_monteith", 0.627)],
     )
     def test_pet(self, method, expected):
-        clm = daymet.get_bygeom(GEOM, DAY, pet=method, ssl=False)
-        assert abs(clm.pet.mean().compute().item() - expected) < SMALL
+        clm = daymet.get_bygeom(GEOM, DAY, pet=method)
+        assert_close(clm.pet.mean().compute().item(), expected)
 
-    @pytest.mark.skipif(hastypeguard and hasnumba, reason="typeguard doesn't work with numba")
+    @pytest.mark.skipif(has_typeguard and has_numba, reason="typeguard doesn't work with numba")
     def test_snow(self):
         clm = daymet.get_bygeom(GEOM, DAY, snow=True, snow_params={"t_snow": 0.5})
-        assert abs(clm.snow.mean().compute().item() - 3.4999) < SMALL
+        assert_close(clm.snow.mean().compute().item(), 3.4999)
 
     def test_bounds(self):
-        clm = daymet.get_bygeom(GEOM.bounds, DAY, ssl=False)
-        assert abs(clm.prcp.mean().compute().item() - 3.4999) < SMALL
+        clm = daymet.get_bygeom(GEOM.bounds, DAY)
+        assert_close(clm.prcp.mean().compute().item(), 3.4999)
 
     def test_daily(self):
-        clm = daymet.get_bygeom(GEOM, DAY, variables=VAR, ssl=False)
-        assert abs(clm.tmin.mean().compute().item() - (-9.421)) < SMALL
+        clm = daymet.get_bygeom(GEOM, DAY, variables=VAR)
+        assert_close(clm.tmin.mean().compute().item(), -9.421)
 
     def test_monthly(self):
-        clm = daymet.get_bygeom(GEOM, YEAR, variables=VAR, time_scale="monthly", ssl=False)
-        assert abs(clm.tmin.mean().compute().item() - 1.311) < SMALL
+        clm = daymet.get_bygeom(GEOM, YEAR, variables=VAR, time_scale="monthly")
+        assert_close(clm.tmin.mean().compute().item(), 1.311)
 
     def test_annual(self):
-        clm = daymet.get_bygeom(GEOM, YEAR, variables=VAR, time_scale="annual", ssl=False)
-        assert abs(clm.tmin.mean().compute().item() - 1.361) < SMALL
+        clm = daymet.get_bygeom(GEOM, YEAR, variables=VAR, time_scale="annual")
+        assert_close(clm.tmin.mean().compute().item(), 1.361)
 
     def test_region(self):
         hi_ext = (-160.3055, 17.9539, -154.7715, 23.5186)
         pr_ext = (-67.9927, 16.8443, -64.1195, 19.9381)
-        hi = daymet.get_bygeom(
-            hi_ext, YEAR, variables=VAR, region="hi", time_scale="annual", ssl=False
-        )
-        pr = daymet.get_bygeom(
-            pr_ext, YEAR, variables=VAR, region="pr", time_scale="annual", ssl=False
-        )
+        hi = daymet.get_bygeom(hi_ext, YEAR, variables=VAR, region="hi", time_scale="annual")
+        pr = daymet.get_bygeom(pr_ext, YEAR, variables=VAR, region="pr", time_scale="annual")
 
-        assert (
-            abs(hi.prcp.mean().compute().item() - 1035.233) < SMALL
-            and abs(pr.tmin.mean().compute().item() - 21.441) < SMALL
-        )
+        assert_close(hi.prcp.mean().compute().item(), 1035.233)
+        assert_close(pr.tmin.mean().compute().item(), 21.441)
 
 
 class TestCLI:
